/// <reference path="../types/jsx.d.ts" />
import { React, Fragment } from "../deps.ts";
import Base from "./_base.tsx";
import DB, { IPackage } from "../db.ts";
import { sortVersions } from "../utils.ts";

function Package({ pkg }: { pkg: IPackage }) {
   const { name, versions, author, description } = pkg;

   const sorted = versions.sort(sortVersions).reverse();

   return (
      <div
         class="card margin"
         onClick={"window.location.href = '/package/" + name + "'"}
      >
         <div class="card-body">
            <h4 class="card-title">
               {name} <span class="badge">{sorted[0]}</span>
            </h4>
            <h5 class="card-subtitle">By {author}</h5>
            <div class="card-text">
               {/* {versions.map((version) => (
                  <li>{version}</li>
               ))} */}
               {description}
            </div>
         </div>
      </div>
   );
}

import { Main, Menu } from "./_default.tsx";

export default async function index({ search }: any) {
   let packages: IPackage[] = [];
   if (search && search !== "") {
      packages = await DB.package.find({
         name: RegExp(`${search}`),
      });
   } else {
      packages = await DB.package.find({});
   }

   return (
      <Base>
         <Main>
            <form method="GET" action="./">
               <div class="form-group margin">
                  {/* <label for="searchInput">Search</label> */}
                  <div style="display:flex">
                     <input
                        placeholder="Search..."
                        class="input-block"
                        type="text"
                        id="searchInput"
                        name="q"
                        value={search}
                     />
                     <button>Submit</button>
                  </div>
               </div>
            </form>
            {packages.map((pkg) => (
               <Package pkg={pkg} />
            ))}
         </Main>
         <Menu>
            <ul>
               <li>Item</li>
            </ul>
         </Menu>
      </Base>
   );
}
